==> xmlworker-1.1.3-sources.jar: com/itextpdf/tool/xml/css/HeightCalculator.java <==
/*
 * $Id:  $
 *
 * This file is part of the iText (R) project.
 * Copyright (c) 1998-2012 1T3XT
 * BVBA Authors: Bruno Lowagie, Balder Van Camp, et al.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT, 1T3XT DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details. You should have received a copy of the GNU Affero General Public
 * License along with this program; if not, see http://www.gnu.org/licenses or
 * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA, 02110-1301 USA, or download the license from the following URL:
 * http://itextpdf.com/terms-of-use/
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License, a
 * covered work must retain the producer line in every PDF that is created or
 * manipulated using iText.
 *
 * You can be released from the requirements of the license by purchasing a
 * commercial license. Buying such a license is mandatory as soon as you develop
 * commercial activities involving the iText software without disclosing the
 * source code of your own applications. These activities include: offering paid
 * services to customers as an ASP, serving PDFs on the fly in a web
 * application, shipping iText with a closed source product.
 *
 * For more information, please contact iText Software Corp. at this address:
 * sales@itextpdf.com
 */
 package com.itextpdf.tool.xml.css;

import com.itextpdf.tool.xml.Tag;
import com.itextpdf.tool.xml.html.HTML;

/**
 *
 */
public class HeightCalculator {
    private final CssUtils utils = CssUtils.getInstance();

    public Float getHeight(final Tag tag, final float pageHeight){
		Float height = null;
		String heightValue = tag.getCSS().get(HTML.Attribute.HEIGHT);
		if(heightValue == null) {
			heightValue = tag.getAttributes().get(HTML.Attribute.HEIGHT);
		}
		if(heightValue != null) {
			if(utils.isNumericValue(heightValue) || utils.isMetricValue(heightValue)) {
				height = utils.parsePxInCmMmPcToPt(heightValue);
			} else if (utils.isRelativeValue(heightValue)) {
				Tag ancestor = tag;
				float firstAncestorsWidth = 0;
				while(firstAncestorsWidth == 0 && ancestor.getParent() != null) {
					ancestor = ancestor.getParent();
					firstAncestorsWidth = getHeight(ancestor, pageHeight);
				}
				if (firstAncestorsWidth == 0) {
					height = utils.parseRelativeValue(heightValue, pageHeight);
				} else {
					height = utils.parseRelativeValue(heightValue, firstAncestorsWidth);
				}
			}
		}

		return height;
	}
}

==> xmlworker-5.4.1-sources.jar: com/itextpdf/tool/xml/css/HeightCalculator.java <==
/*
 * $Id: HeightCalculator.java 341 2012-06-18 14:38:54Z blowagie $
 *
 * This file is part of the iText (R) project.
 * Copyright (c) 1998-2012 1T3XT
 * BVBA Authors: Bruno Lowagie, Balder Van Camp, et al.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT, 1T3XT DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details. You should have received a copy of the GNU Affero General Public
 * License along with this program; if not, see http://www.gnu.org/licenses or
 * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA, 02110-1301 USA, or download the license from the following URL:
 * http://itextpdf.com/terms-of-use/
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License, a
 * covered work must retain the producer line in every PDF that is created or
 * manipulated using iText.
 *
 * You can be released from the requirements of the license by purchasing a
 * commercial license. Buying such a license is mandatory as soon as you develop
 * commercial activities involving the iText software without disclosing the
 * source code of your own applications. These activities include: offering paid
 * services to customers as an ASP, serving PDFs on the fly in a web
 * application, shipping iText with a closed source product.
 *
 * For more information, please contact iText Software Corp. at this address:
 * sales@itextpdf.com
 */
 package com.itextpdf.tool.xml.css;

import com.itextpdf.tool.xml.Tag;
import com.itextpdf.tool.xml.html.HTML;

/**
 *
 */
public class HeightCalculator {
    private final CssUtils utils = CssUtils.getInstance();

    public Float getHeight(final Tag tag, final float pageHeight){
		Float height = null;
		String heightValue = tag.getCSS().get(HTML.Attribute.HEIGHT);
		if(heightValue == null) {
			heightValue = tag.getAttributes().get(HTML.Attribute.HEIGHT);
		}
		if(heightValue != null) {
			if(utils.isNumericValue(heightValue) || utils.isMetricValue(heightValue)) {
				height = utils.parsePxInCmMmPcToPt(heightValue);
			} else if (utils.isRelativeValue(heightValue)) {
				Tag ancestor = tag;
				Float firstAncestorsWidth = null;
				while(firstAncestorsWidth == null && ancestor.getParent() != null) {
					ancestor = ancestor.getParent();
					firstAncestorsWidth = getHeight(ancestor, pageHeight);
				}
				if (firstAncestorsWidth == null) {
					height = utils.parseRelativeValue(heightValue, pageHeight);
				} else {
					height = utils.parseRelativeValue(heightValue, firstAncestorsWidth);
				}
			}
		}

		return height;
	}
}
